#
# spec file for package libjnidispatch
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2009, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libjnidispatch
Version:        4.1.0
Release:        8.4
Summary:        Java Native Access (shared library)
License:        LGPL-2.1+ or Apache-2.0
Group:          Development/Libraries/Java
Url:            https://github.com/twall/jna
Source0:        https://github.com/twall/jna/archive/%{version}.tar.gz
Source1:        jna-%{version}.pom
Source2:        libjnidispatch-rpmlintrc
Patch0:         jna-%{version}-build.patch
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  java-devel >= 1.5.0
BuildRequires:  javapackages-tools
BuildRequires:  junit
Requires:       java >= 1.5.0
Provides:       jna-native = %{version}-%{release}
Obsoletes:      jna-native < %{version}-%{release}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  dos2unix
BuildRequires:  libffi-devel
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  xorg-x11-libXt-devel

%description
Native library stub to dynamically invoke native code used by Java Native
Access library.

%package -n jna
Summary:        Java Native Access
Group:          Development/Libraries/Java
%if 0%{suse_version} > 1110
BuildArch:      noarch
%endif
Requires:       libjnidispatch

%description -n jna
JNA provides Java programs easy access to native shared libraries without
writing anything but Java code. No JNI or native code is required. This
functionality is comparable to Windows' Platform/Invoke and Python's ctypes.
Access is dynamic at runtime without code generation.  JNA's design aims to
provide native access in a natural way with a minimum of effort. No boilerplate
or generated code is required. While some attention is paid to performance,
correctness and ease of use take priority.

The JNA library uses a small native library (%{name}) stub to dynamically
invoke native code. The developer uses a Java interface to describe functions
and structures in the target native library.  This makes it quite easy to take
advantage of native platform features without incurring the high overhead of
configuring and building JNI code for multiple platforms.

%package -n jna-javadoc
Summary:        Javadoc for Java Native Access
Group:          Documentation/HTML
%if 0%{suse_version} > 1110
BuildArch:      noarch
%endif

%description -n jna-javadoc
Javadoc reference for the Java Native Access library.

%prep
%setup -q -n jna-%{version}
# Cleanup the dist tarball
find . -name '*jar' | xargs rm
rm -rf dist
dos2unix OTHERS
# Then apply patches
%patch0 -p1 -b .orig

#FIXME: DirectTest fails
rm test/com/sun/jna/DirectTest.java test/com/sun/jna/PerformanceTest.java

sed -i 's|soname,\$@|soname,%{name}.so|' native/Makefile

%build

ant \
    jar \
    native \
    platform-jar \
    -Dcflags_extra.native="%{optflags}" \
    -Dbuild-native=true \
    -Dcompatibility=1.5 \
    -Ddynlink.native=true \
    javadoc

%install
if [ -d build-d64 ]; then
suffix="-d64"
fi

install -d -m 755 %{buildroot}%{_libdir}
install -p -m 644 build${suffix}/native-*/libjnidispatch.so %{buildroot}%{_libdir}/libjnidispatch.so

install -d -m 755 %{buildroot}%{_javadir}
install -p -m 644 build${suffix}/jna.jar %{buildroot}%{_javadir}/jna.jar
install -p -m 644 ./contrib/platform/dist/jna-platform.jar %{buildroot}%{_javadir}/jna-platform.jar

install -d -m 755 %{buildroot}%{_mavenpomdir}
# let's name maven fragment jna as expected
install -p -m 644 %{SOURCE1} %{buildroot}/%{_mavenpomdir}/JPP-jna.pom
%add_maven_depmap JPP-jna.pom jna.jar
mv %{buildroot}/%{_mavendepmapfragdir}/%{name} %{buildroot}/%{_mavendepmapfragdir}/jna

install -d -m 755 %{buildroot}%{_javadocdir}/jna
cp -pr doc/javadoc/* %{buildroot}%{_javadocdir}/jna

%files
%defattr(0644,root,root,0755)
%doc LICENSE
%attr(0755,root,root) %{_libdir}/libjnidispatch.so

%files -n jna
%defattr(0644,root,root,0755)
%doc CHANGES.md LICENSE OTHERS README.md TODO
%{_javadir}/jna.jar
%{_javadir}/jna-platform.jar
%{_mavenpomdir}/JPP-jna.pom
%{_mavendepmapfragdir}/jna

%files -n jna-javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/jna

%changelog
* Mon Nov  3 2014 cbosdonnat@suse.com
- Updated to 4.1.0. See the changelog on:
  https://github.com/twall/jna/blob/master/CHANGES.md
- Updated jna-3.4.0-build.patch into jna-4.1.0-build.patch
- Added libjnidispatch.rpmlintrc to silence warning about explicit
  library dependency between jna and libjnidistach: rpm doesn't
  detect library dependencies on Java packages, we need to force it.
- Removed libffi patches: now using the libffi package.
  * libffi-aarch64.patch
  * libffi-ppc64le.patch
- Added rpmlint filters:
  * libjnidispatch-rpmlintrc
* Tue Jul  8 2014 tchvatal@suse.com
- Do not depend on ant-trax and run spec-cleaner.
* Mon Dec  9 2013 dvaleev@suse.com
- enable ppc64le
- added patches:
  * libffi-ppc64le.patch
* Wed Sep 11 2013 mvyskocil@suse.com
- use add_maven_depmap from javapackages-tools
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Thu Apr 11 2013 schwab@suse.de
- libffi-aarch64.patch: import aarch64 support for libffi
* Wed Dec 12 2012 dvaleev@suse.com
- enable ppc and ppc64 builds
* Wed Nov 14 2012 mvyskocil@suse.com
- fix a build for non-suse distros
* Tue Jun 19 2012 mvyskocil@suse.cz
- fix a build with jdk7
- rename to libjnidispatch to follow packaging policy (provides jna-native)
- jna and jna-javadoc are now noarch subpackages of it
- don't strip a binary during a build
* Thu Feb  9 2012 mvyskocil@suse.cz
- Update to 3.4.0
  * moved object creation out into pure Java code reduce JNI crossing
  * add native peer value accessors for Pointer
  * avoid loading any system-provided JNA via jna.nosys=true
  * override default jnidispatch library name with jna.boot.library
  * throw an error if JNA is not with a library
  * linux/arm and linux/ppc 32-bit support
  * preliminary linux/ppc64 support
  * linux multi-arch support (kohsuke).
  * add to `platform.unix.x11`: `XGrabKey`, `XUngrabKey`, `XSetErrorHandler`.
  * and a lot of bugfixes (see /usr/share/packages/doc/jna/README.md)
- fix bnc#745571 enable build of jna-native as well
* Thu Apr  8 2010 mvyskocil@suse.cz
- update to 3.1.0 (jna-3.1.0-2.jpp6.src.rpm)
  * raw JNI mapping of static Java methods increased performance
  * library option to allow passing/return of Java Objects.
  * handling of uncaught callback exceptions (Issue 63).
  * object oriented interface to X server (see contrib/x11)
  * Memory class more accessible.
  * allow implicit library access to current process on linux (issue 98).
  * open all shared libraries with RTLD_GLOBAL, if applicable. This was the default behavior on OSX and changes the default behavior on linux.
  * allow NIO Buffer as Structure field (with limitations) (Issue 57)
  * add size_t size.
  * Bug Fixes
* Mon Jun  1 2009 mvyskocil@suse.cz
- fixed bnc#507734:  jna declared LGPL but contains GPL files and binaries
  * removed all jars from source archive
  * added gpl to docdir
* Tue May 19 2009 mvyskocil@suse.cz
- 'Initial SUSE packaging from jpackage.org 5.0'
